@@ -2,17 +2,18 @@ package AnyEvent::Filesys::Notify;
 
 # ABSTRACT: An AnyEvent compatible module to monitor files/directories for changes
 
-use Moose;
-use Moose::Util qw(apply_all_roles);
-use namespace::autoclean;
+use Moo;
+use Moo::Role ();
+use MooX::late;
+use namespace::sweep;
 use AnyEvent;
-use File::Find::Rule;
+use Path::Iterator::Rule;
 use Cwd qw/abs_path/;
 use AnyEvent::Filesys::Notify::Event;
 use Carp;
 use Try::Tiny;
 
-our $VERSION = '0.20_02';
+our $VERSION = '0.23_10';
 my $AEFN = 'AnyEvent::Filesys::Notify';
 
 has dirs        => ( is => 'ro', isa => 'ArrayRef[Str]', required => 1 );
@@ -74,7 +75,9 @@ sub _scan_fs {
 
     my $fs_stats = {};
 
-    for my $file ( File::Find::Rule->in(@paths) ) {
+    my $rule = Path::Iterator::Rule->new;
+    my $next = $rule->iter(@paths);
+    while ( my $file = $next->() ) {
         my $stat = _stat($file)
           or next; # Skip files that we can't stat (ie, broken symlinks on ext4)
         $fs_stats->{ abs_path($file) } = $stat;
@@ -166,44 +169,42 @@ sub _load_backend {
         my $backend = $self->backend;
         $backend = $prefix . $backend unless $backend =~ s{^\+}{};
 
-        try { apply_all_roles( $self, $backend ); }
+        try { Moo::Role->apply_roles_to_object( $self, $backend ); }
         catch {
             croak "Unable to load the specified backend ($backend). You may "
               . "need to install Linux::INotify2, Mac::FSEvents or IO::KQueue:"
               . "\n$_";
         }
     } elsif ( $self->no_external ) {
-        apply_all_roles( $self, "${AEFN}::Role::Fallback" );
+        Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Fallback" );
     } elsif ( $^O eq 'linux' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::Inotify2" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Inotify2"); }
         catch {
             croak "Unable to load the Linux plugin. You may want to install "
               . "Linux::INotify2 or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } elsif ( $^O eq 'darwin' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::FSEvents" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::FSEvents" ); }
         catch {
             croak "Unable to load the Mac plugin. You may want to install "
               . "Mac::FSEvents or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } elsif ( $^O eq 'freebsd' ) {
-        try { apply_all_roles( $self, "${AEFN}::Role::KQueue" ); }
+        try { Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::KQueue" ); }
         catch {
             croak "Unable to load the FreeBSD plugin. You may want to install "
               . "IO::KQueue or specify 'no_external' (but that is very "
               . "inefficient):\n$_";
         }
     } else {
-        apply_all_roles( $self, "${AEFN}::Role::Fallback" );
+        Moo::Role->apply_roles_to_object( $self, "${AEFN}::Role::Fallback" );
     }
 
     return 1;
 }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -216,7 +217,7 @@ AnyEvent::Filesys::Notify - An AnyEvent compatible module to monitor files/direc
 
 =head1 VERSION
 
-version 0.20_02
+version 0.23_10
 
 =head1 SYNOPSIS
 
@@ -272,9 +273,9 @@ Specifies the time in fractional seconds between file system checks for
 the L<AnyEvent::Filesys::Notify::Role::Fallback> implementation.
 
 Specifies the latency for L<Mac::FSEvents> for the
-C<AnyEvent::Filesys::Notify::Role::Mac> implementation.
+C<AnyEvent::Filesys::Notify::Role::FSEvents> implementation.
 
-Ignored for the C<AnyEvent::Filesys::Notify::Role::Linux> implementation.
+Ignored for the C<AnyEvent::Filesys::Notify::Role::Inotify2> implementation.
 
 =item filter
 
@@ -317,16 +318,26 @@ not require either L<Linux::INotify2> nor L<Mac::FSEvents>. Optional.
 
 =head1 WATCHER IMPLEMENTATIONS
 
-=head2 Linux
+=head2 INotify2 (Linux)
 
 Uses L<Linux::INotify2> to monitor directories. Sets up an C<AnyEvent-E<gt>io>
 watcher to monitor the C<$inotify-E<gt>fileno> filehandle.
 
-=head2 Mac
+=head2 FSEvents (Mac)
 
 Uses L<Mac::FSEvents> to monitor directories. Sets up an C<AnyEvent-E<gt>io>
 watcher to monitor the C<$fsevent-E<gt>watch> filehandle.
 
+=head2 KQueue (FreeBSD/Mac)
+
+Uses L<IO::KQueue> to monitor directories. Sets up an C<AnyEvent-E<gt>io>
+watcher to monitor the C<IO::KQueue> object.
+
+B<WARNING> - L<IO::KQueue> and the C<kqueue()> system call require an open
+filehandle for every directory and file that is being watched. This makes
+it impossible to watch large directory structures (and inefficient to watch
+moderately sized directories). The use of the KQueue backend is discouraged.
+
 =head2 Fallback
 
 A simple scan of the watched directories at regular intervals. Sets up an
