@@ -2,7 +2,9 @@ package AnyEvent::Filesys::Notify::Event;
 
 # ABSTRACT: Object to report changes in the monitored filesystem
 
-use Moose;
+use Moo;
+use MooX::late;
+use namespace::sweep;
 
 has path => ( is => 'ro', isa => 'Str', required => 1 );
 has type => ( is => 'ro', isa => 'Str', required => 1 );
@@ -30,7 +32,7 @@ AnyEvent::Filesys::Notify::Event - Object to report changes in the monitored fil
 
 =head1 VERSION
 
-version 0.20_02
+version 0.23_10
 
 =head1 SYNOPSIS
 
